@@ -31,9 +31,10 @@
 #' results, default is \code{NULL}.
 #'
 #' @details To know which hyperparameters can be tuned you can use the output of
-#' the function \code{\link{get_tunable_args}}. Parallel computation increases
-#' the speed only for large datasets due to the time necessary to create the
-#' cluster. Part of the code is inspired by
+#' the function \code{\link{get_tunable_args}}. Hyperparameters not included in
+#' the \code{hypers} argument take the value that they have in the passed model.
+#' Parallel computation increases the speed only for large datasets due to the
+#' time necessary to create the cluster. Part of the code is inspired by
 #' \href{https://blog.coast.ai/lets-evolve-a-neural-network-with-a-geneticalgorithm-code-included-8809bece164}{this post}.
 #'
 #' @return \linkS4class{SDMtune} object.
@@ -341,7 +342,7 @@ optimizeModel <- function(model, hypers, metric, test = NULL, bg4test = NULL,
     }
   }
 
-  new_model <- do.call("train", model_args)
+  new_model <- suppressMessages(do.call("train", model_args))
 
   return(new_model)
 }
